@@ -454,6 +454,14 @@ class Variables(Container):
 
             var.setup_initial_conditions(ics, self.di, functions)
 
+        for var_name in self.parameter:
+            var = self[var_name]
+            if hasattr(var, 'special') and ('ic' in var.special):
+                setter, sargs, skwargs = var._get_setter('ic', functions)
+
+                var.set_data(setter(*sargs, **skwargs))
+                output('IC data of %s set by %s()' % (var.name, setter.name))
+
     def set_adof_conns(self, adof_conns):
         """
         Set all active DOF connectivities to `self` as well as relevant
@@ -1332,9 +1340,9 @@ class FieldVariable(Variable):
     """
 
     def __init__(self, name, kind, field, order=None, primary_var_name=None,
-                 special=None, flags=None, **kwargs):
+                 special=None, flags=None, history=None, **kwargs):
         Variable.__init__(self, name, kind, order, primary_var_name,
-                          special, flags, **kwargs)
+                          special, flags, history=history, **kwargs)
 
         self._set_field(field)
 
@@ -1361,6 +1369,33 @@ class FieldVariable(Variable):
 
         self.dim = field.domain.shape.dim
 
+    def _get_setter(self, kind, functions, **kwargs):
+        """
+        Get the setter function of the variable and its arguments depending in
+        the setter kind.
+        """
+        if not (hasattr(self, 'special') and (kind in self.special)):
+            return
+
+        setter_name = self.special[kind]
+        setter = functions[setter_name]
+
+        region = self.field.region
+        nod_list = self.field.get_dofs_in_region(region)
+        nods = nm.unique(nm.hstack(nod_list))
+
+        coors = self.field.get_coor(nods)
+
+        if kind == 'setter':
+            sargs = (kwargs.get('ts'), coors)
+
+        elif kind == 'ic':
+            sargs = (coors, )
+
+        skwargs = {'region' : region}
+
+        return setter, sargs, skwargs
+
     def get_field(self):
         return self.field
 
@@ -1429,16 +1464,11 @@ class FieldVariable(Variable):
             self.dt = ts.dt
 
         if hasattr(self, 'special') and ('setter' in self.special):
-            setter_name = self.special['setter']
-            setter = functions[setter_name]
+            setter, sargs, skwargs = self._get_setter('setter', functions,
+                                                      ts=ts)
 
-            region = self.field.region
-            nod_list = self.field.get_dofs_in_region(region)
-            nods = nm.unique(nm.hstack(nod_list))
-
-            coor = self.field.get_coor(nods)
-            self.set_data(setter(ts, coor, region=region))
-            output('data of %s set by %s()' % (self.name, setter_name))
+            self.set_data(setter(*sargs, **skwargs))
+            output('data of %s set by %s()' % (self.name, setter.name))
 
     def set_data_from_qp(self, data_qp, integral, step=0):
         """
